@@ -42,8 +42,12 @@ def align_main(ref, r1, r2, sam_path, shfile, rc=False, header=""):
         r1_cmd = f"bowtie2 --no-head --norc --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r1} -S {r1_sam_file}"
         r2_cmd = f"bowtie2 --no-head --nofw --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r2} -S {r2_sam_file}"
     else:
-        r1_cmd = f"bowtie2 --no-head --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r1} -S {r1_sam_file}"
-        r2_cmd = f"bowtie2 --no-head --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r2} -S {r2_sam_file}"
+        # command changed here to match Ian's flags
+        r1_cmd = f"bowtie2 --no-head --no-sq --rdg 6,4 --rfg 6,4 -x {ref} -U {r1} -S {r1_sam_file}"
+        r2_cmd = f"bowtie2 --no-head --no-sq --rdg 6,4 --rfg 6,4 -x {ref} -U {r2} -S {r2_sam_file}"
+
+        # r1_cmd = f"bowtie2 --no-head --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r1} -S {r1_sam_file}"
+        # r2_cmd = f"bowtie2 --no-head --no-sq --rdg 12,1 --rfg 12,1 --local -x {ref} -U {r2} -S {r2_sam_file}"
 
     with open(shfile, "w") as f:
         # header is only used on galen
